@@ -553,6 +553,7 @@ typedef enum {
  * @PK_GROUP_ENUM_COLLECTIONS:
  * @PK_GROUP_ENUM_VENDOR: Vendor defined group
  * @PK_GROUP_ENUM_NEWEST: Special group for recently updated packages
+ * @PK_GROUP_ENUM_DESKTOP_DDE: DDE packages
  * @PK_GROUP_ENUM_LAST:
  *
  * The group type
@@ -593,6 +594,7 @@ typedef enum {
 	PK_GROUP_ENUM_COLLECTIONS,
 	PK_GROUP_ENUM_VENDOR,
 	PK_GROUP_ENUM_NEWEST,
+	PK_GROUP_ENUM_DESKTOP_DDE,
 	PK_GROUP_ENUM_LAST
 } PkGroupEnum;
 
@@ -642,6 +644,7 @@ typedef enum {
  * @PK_INFO_ENUM_UNTRUSTED:
  * @PK_INFO_ENUM_TRUSTED:
  * @PK_INFO_ENUM_UNAVAILABLE: Package is unavailable
+ * @PK_INFO_ENUM_CRITICAL: Update severity is critical; Since: 1.2.4
  * @PK_INFO_ENUM_LAST:
  *
  * The enumerated types used in Package() - these have to refer to a specific
@@ -674,6 +677,7 @@ typedef enum {
 	PK_INFO_ENUM_UNTRUSTED,
 	PK_INFO_ENUM_TRUSTED,
 	PK_INFO_ENUM_UNAVAILABLE,
+	PK_INFO_ENUM_CRITICAL,	/* Since: 1.2.4 */
 	PK_INFO_ENUM_LAST
 } PkInfoEnum;
 
